GH_ORGANIZATION_NAME = "Distyopoly"
FRAMEWORK_REPO = "disty-craft"
TEMPORARY_ZIP_BASENAME = ".disty.craft"
FRAMEWORK_RELATIVE_PATH = ".disty-craft"

LOCK_FILE_RELATIVE_PATH = FRAMEWORK_RELATIVE_PATH + "/.disty-craft.lock"
